@@ -4,8 +4,10 @@
 from email.MIMEText import MIMEText
 from email.MIMEMultipart import MIMEMultipart
 import smtplib
+import ssl
 import time
 from weberror import formatter
+from email.utils import formatdate
 
 class Reporter(object):
 
@@ -54,8 +56,8 @@ class EmailReporter(Reporter):
                         self.to_addresses, msg.as_string())
         try:
             server.quit()
-        except sslerror:
-            # sslerror is raised in tls connections on closing sometimes
+        except ssl.SSLError:
+            # SSLError is raised in tls connections on closing sometimes
             pass
 
     def check_params(self):
@@ -93,6 +95,7 @@ class EmailReporter(Reporter):
         msg['Subject'] = as_str(self.subject_prefix) + subject
         msg['From'] = as_str(self.from_address)
         msg['To'] = as_str(', '.join(self.to_addresses))
+        msg['Date'] = formatdate()
         return msg
 
 class LogReporter(Reporter):
@@ -123,7 +126,7 @@ class FileReporter(Reporter):
             "You must give a file object")
 
     def report(self, exc_data):
-        text = self.format_text(
+        text, head_text = self.format_text(
             exc_data, show_hidden_frames=self.show_hidden_frames)
         self.file.write(text + '\n' + '-'*60 + '\n')
 
